@@ -44,6 +44,11 @@ from solfege import utils
 
 import solfege
 
+try:
+    from pyalsa import alsaseq
+except ImportError:
+    alsaseq = None
+
 solfege_copyright = u"Copyright © 1999-2008 Tom Cato Amundsen <tca@gnu.org>, and others."
 
 warranty = """
@@ -191,6 +196,28 @@ class SolfegeApp(cfg.ConfigUtils):
         if self.m_options.no_sound \
            or cfg.get_string("sound/type") == "fake-synth":
             soundcard.initialise_using_fake_synth(self.m_options.verbose_sound_init)
+        elif cfg.get_string("sound/type") == "alsa-sequencer":
+            if alsaseq:
+                try:
+                    clientid, portid = self.get_list("sound/alsa-client-port")
+                except ValueError:
+                    clientid, portid = (None, None)
+                try:
+                    soundcard.initialise_alsa_sequencer((clientid, portid), 
+                            self.m_options.verbose_sound_init)
+                except NameError, e:
+                    gu.display_exception_message(e)
+                    return
+                except ImportError, e:
+                    solfege.win.display_error_message2(_("The pyalsa python module is missing"),
+                    _("Sound config have been reset. You must reconfigure sound in the prefernces window (Ctrl-F12)."))
+                    cfg.set_string("sound/type", "fake-synth")
+                    soundcard.initialise_using_fake_synth(self.m_options.verbose_sound_init)
+                except alsaseq.SequencerError, e:
+                    solfege.win.display_error_message2(unicode(e),
+                    _("Sound config have been reset. You must reconfigure sound in the prefernces window (Ctrl-F12)."))
+                    cfg.set_string("sound/type", "fake-synth")
+                    soundcard.initialise_using_fake_synth(self.m_options.verbose_sound_init)
         elif cfg.get_string("sound/type") == "winsynth":
             try:
                 soundcard.initialise_winsynth(cfg.get_int("sound/synth_number"),
